@@ -136,13 +136,6 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
         default=450,
         scope=Scope.settings,
     )
-
-    fullscreen_on_launch = Boolean(
-        display_name=_("Fullscreen on launch"),
-        help=_("Display in fullscreen mode on launch"),
-        default=False,
-        scope=Scope.settings,
-    )
     popup_on_launch = Boolean(
         display_name=_("Launch in pop-up window"),
         help=_(
@@ -201,7 +194,6 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
             "ScormXBlock",
             json_args={
                 "scorm_version": self.scorm_version,
-                "fullscreen_on_launch": self.fullscreen_on_launch,
                 "popup_on_launch": self.popup_on_launch,
                 "popup_width": self.width or 800,
                 "popup_height": self.height or 800,
@@ -219,7 +211,6 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
             "field_weight": self.fields["weight"],
             "field_width": self.fields["width"],
             "field_height": self.fields["height"],
-            "field_fullscreen_on_launch": self.fields["fullscreen_on_launch"],
             "field_popup_on_launch": self.fields["popup_on_launch"],
             "scorm_xblock": self,
         }
@@ -244,7 +235,6 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
         self.height = parse_int(request.params["height"], None)
         self.has_score = request.params["has_score"] == "1"
         self.weight = parse_float(request.params["weight"], 1)
-        self.fullscreen_on_launch = request.params["fullscreen_on_launch"] == "1"
         self.popup_on_launch = request.params["popup_on_launch"] == "1"
         self.icon_class = "problem" if self.has_score else "video"
 
